
from elasticsearch import Elasticsearch
import os

CA_ROOT = os.path.join(os.path.dirname(__file__), 'root-ca.pem')
hosts = ['https://es%s.ceda.ac.uk:9200' % i for i in range(9,17)]

class CEDAElasticsearchClient(Elasticsearch):
    """
    Wrapper class to handle SSL authentication with the correct root
    certificate for the cluster. This subclass provides defaults for kwargs from
    the main Elasticsearch Python client.
    
    For read use cases, where the indices of interest are publically available, it will be sufficient to call:
    
    es = CEDAElasticsearchClient()
    
    For application access, which requires write permissions, you will need to provide an API key. This can be done:
    
    es =  CEDAElasticsearchClient(headers={'x-api-key':'YOUR-API-KEY'})
     or 
    es =  CEDAElasticsearchClient(api_key = 'YOUR-API-KEY')
    
    For further customisations see the Python Elasticsearch client documentation
    """

    def __init__(self, hosts=hosts, ca_certs=CA_ROOT, api_key=None, **kwargs):
 
        if api_key is not None: 
            if "headers" in kwargs: 
                kwargs["headers"]["x-api-key"] = api_key
            else:
                kwargs["headers"] = {'x-api-key': api_key}

        super(CEDAElasticsearchClient, self).__init__(
            hosts=hosts,
            ca_certs=ca_certs,
            **kwargs
        )





# Always prefer setuptools over distutils
from setuptools import setup, find_packages
import os

here = os.path.abspath(os.path.dirname(__file__))

# Get the long description from the relevant file
# with open(path.join(here, 'README.md'), encoding='utf-8') as f:
#    long_description = f.read()
long_description = open(os.path.join(here, "README.md")).read()

setup(
    name='ceda-elasticsearch-client',
    version='0.0.1',
    description='CEDA elasticsearch client',
    long_description=long_description,

    # Author details
    author='Sam Pepler',
    author_email='sam.pepler@stfc.ac.uk',
    license='BSD',

    # See https://pypi.python.org/pypi?%3Aaction=list_classifiers
    classifiers=[
        'Development Status :: 5 - Production/Stable',
        # Indicate who your project is intended for
        'Intended Audience :: Developers',
        # Pick your license as you wish (should match "license" above)
        'License :: OSI Approved :: BSD License',
        # Specify the Python versions you support here. In particular, ensure
        # that you indicate whether you support Python 2, Python 3 or both.
        'Programming Language :: Python :: 3',
    ],
    packages=['ceda_es_client'],

    package_data={
        'ceda_es_client': ['root-ca.pem'],
    },
    # jar: Need to install Slacker library
    install_requires=['elasticsearch'],
)